# -*- coding: utf-8 -*-


class HelloWorld(object):

    def __init__(self):
        print('Hello World')
